import { ICreateForumsDTO } from "@modules/foruns/dtos/ICreateForumDTO";
import { Forum } from "@prisma/client";
import prismaClient from "@shared/infra/prisma";
import { IForumRepository } from "../IForumRepository";

class ForumRepository implements IForumRepository {
    async create({ title, description }: ICreateForumsDTO): Promise<Forum> {
        const forum = await prismaClient.forum.create({
            data: {
                title,
                description
            }
        })

        return forum
    }

    async findById(id: string): Promise<Forum> {
        const forum = await prismaClient.forum.findUnique({
            where: { id }
        })

        return forum as Forum
    }

    async findByTitle(title: string): Promise<Forum> {
        const forum = await prismaClient.forum.findFirst({
            where: { title }
        })

        return forum as Forum
    }

    async deleteForum(id: string): Promise<Boolean> {
        await prismaClient.forum.delete({
            where: { id }
        })

        return true
    }

    async findAllForuns(): Promise<Forum[]> {
        const foruns = await prismaClient.forum.findMany()
        return foruns
    }
}

export { ForumRepository }